@@ -2,26 +2,25 @@ import logging
 import sys
 logging.basicConfig(level=logging.DEBUG, stream=sys.stdout)
 
-import mqtt as mqtt
+from rpi2mqtt.mqtt import MQTT 
 import time
 
-# logging.getLogger().setLevel(logging.DEBUG)
 
 def main():
     logging.debug('debug message')
     logging.info('info message')
     logging.warning('warning')
     logging.error('error')
-    mqtt.setup()
+    MQTT.setup()
 
 def test_mqtt_subscribe():
-    mqtt.setup()
+    MQTT.setup()
 
     def callback(client, data, message):
         print(message.payload)
 
     while True:
-        res, id = mqtt.subscribe('hello', callback)
+        res, id = MQTT.subscribe('hello', callback)
         if res == 0:
             break
         time.sleep(1)
