@@ -287,9 +287,9 @@ class HestiaPi(Sensor):
     def append_tempearture_history(self):
         """Save current temperature in _temperature history and maintain N readings."""
          # if system is active log temperature changes for analysis
-        # if self.active:
-        self._temperature_history.append(self.temperature)
-        logging.debug('Temperature history = {}'.format(self._temperature_history))
+        if self.active:
+            self._temperature_history.append(self.temperature)
+            logging.debug('Temperature history = {}'.format(self._temperature_history))
         # if len(self.temperature_history) > 6: # how many readings should we keep track of. 4 is ~20 minutes.
         #     self.temperature_history.pop(0)
 
@@ -382,6 +382,7 @@ class HestiaPi(Sensor):
         if mode in HVAC.HEAT_PUMP_MODES:
             self.mode = mode
             self.last_mode_change_time = pendulum.now()
+            self.callback()
             # Config.save()
         else:
             raise HvacException('{} mode is not a valid HVAC mode'.format(mode))
@@ -460,7 +461,7 @@ class HestiaPi(Sensor):
                 raise HvacException('{} is not a valid boost value. allowed values are [[{},{}]'.format(boost, HVAC.ON, HVAC.OFF))
         # self._boosting_heat = boost
         else:
-            logging.info(f"Boosting disabled by switch. Switch state: {self._boosting_enabled_switch.state}. aux_enabled: {self.aux_enabled}")
+            logging.info(f"Boosting disabled by switch. Switch state: {self._boosting_enabled_switch.state()}. aux_enabled: {self.aux_enabled}")
 
     def should_boost(self):
         if self.mode == HVAC.HEAT and self.temperature_rate_of_change and self.temperature_rate_of_change <= self.minimum_temp_rate_of_change:
@@ -540,6 +541,7 @@ class HVACAuxSwitch(Switch):
     def homeassistant_mqtt_config(self):
         config = super(HVACAuxSwitch, self).homeassistant_mqtt_config
         config['value_template'] = "{{ value_json.aux_enabled }}"
+        config['command_topic'] = "/homeassistant/switch/hestiapi_aux_enabled/set"
         return config
 
     def setup(self, lazy_setup=True):
